@@ -17,6 +17,7 @@
 #' @param scale_y_log10 logical if TRUE add scale_y_log10 layer
 #' @param color.scales \code{list} define scales parameter in case of strat.color \code{\link{pmx_settings}}
 #' @param is.legend \code{logical} if TRUE x axis is discrete(FALSE by default)
+#' @param legend.position \code{charcater} legend position it takes the same value as the equivalent ggplot2 parameter
 #'
 #' @details
 
@@ -45,7 +46,8 @@ pmx_gpar <-
              scale_x_log10,
              scale_y_log10,
              color.scales,
-             is.legend) {
+             is.legend,
+             legend.position) {
 
 
     ## join with default values
