@@ -11,7 +11,7 @@ pmx_theme <- function(...) {
   theme_bw() +
     theme(
       strip.text = element_text(size = 14),
-      strip.background = element_rect(colour = NA, fill = NA),
+      ## strip.background = element_rect( colour = NA),
       plot.title = element_text(size = 12),
       axis.text = element_text(size = 10),
       plot.margin = unit(c(1, 1, 1, 1), "cm"),
